==> openshift-model-6.0.0-sources.jar: io/fabric8/openshift/api/model/TagImageHookFluent.java <==
package io.fabric8.openshift.api.model;

import io.fabric8.kubernetes.api.model.ObjectReference;
import io.fabric8.kubernetes.api.model.ObjectReferenceFluent;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;
import java.util.Map;
import java.util.LinkedHashMap;

 /**
  * Generated
  */
public interface TagImageHookFluent<A extends TagImageHookFluent<A>> extends Fluent<A>{
  public String getContainerName();
  public A withContainerName(String containerName);
  public Boolean hasContainerName();
  
  /**
   * This method has been deprecated, please use method buildTo instead.
   * @return The buildable object.
   */
  @Deprecated
  public ObjectReference getTo();
  public ObjectReference buildTo();
  public A withTo(ObjectReference to);
  public Boolean hasTo();
  public TagImageHookFluent.ToNested<A> withNewTo();
  public TagImageHookFluent.ToNested<A> withNewToLike(ObjectReference item);
  public TagImageHookFluent.ToNested<A> editTo();
  public TagImageHookFluent.ToNested<A> editOrNewTo();
  public TagImageHookFluent.ToNested<A> editOrNewToLike(ObjectReference item);
  public A addToAdditionalProperties(String key,Object value);
  public A addToAdditionalProperties(Map<String,Object> map);
  public A removeFromAdditionalProperties(String key);
  public A removeFromAdditionalProperties(Map<String,Object> map);
  public Map<String,Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties);
  public Boolean hasAdditionalProperties();
  public interface ToNested<N> extends Nested<N>,ObjectReferenceFluent<TagImageHookFluent.ToNested<N>>{
    public N and();
    public N endTo();
    
  }
  
}

==> openshift-model-6.7.2-sources.jar: io/fabric8/openshift/api/model/TagImageHookFluent.java <==
package io.fabric8.openshift.api.model;

import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import io.fabric8.kubernetes.api.model.ObjectReference;
import io.fabric8.kubernetes.api.model.ObjectReferenceFluent;
import java.lang.Deprecated;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public interface TagImageHookFluent<A extends TagImageHookFluent<A>> extends Fluent<A>{
  public String getContainerName();
  public A withContainerName(String containerName);
  public Boolean hasContainerName();
  
  /**
   * This method has been deprecated, please use method buildTo instead.
   * @return The buildable object.
   */
  @Deprecated
  public ObjectReference getTo();
  public ObjectReference buildTo();
  public A withTo(ObjectReference to);
  public Boolean hasTo();
  public TagImageHookFluent.ToNested<A> withNewTo();
  public TagImageHookFluent.ToNested<A> withNewToLike(ObjectReference item);
  public TagImageHookFluent.ToNested<A> editTo();
  public TagImageHookFluent.ToNested<A> editOrNewTo();
  public TagImageHookFluent.ToNested<A> editOrNewToLike(ObjectReference item);
  public A addToAdditionalProperties(String key,Object value);
  public A addToAdditionalProperties(Map<String,Object> map);
  public A removeFromAdditionalProperties(String key);
  public A removeFromAdditionalProperties(Map<String,Object> map);
  public Map<String,Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties);
  public Boolean hasAdditionalProperties();
  public interface ToNested<N> extends Nested<N>,ObjectReferenceFluent<TagImageHookFluent.ToNested<N>>{
    public N and();
    public N endTo();
    
  }
  
}
